document.addEventListener('DOMContentLoaded', function() { 

    // Obtener la dirección IP del div .mobileaccess si existe
    const mobileAccessDiv = document.querySelector('.mobileaccess');
    const baseURL = mobileAccessDiv ? `http://${mobileAccessDiv.textContent.trim()}/` : '/';

    function attachEvents(id) {
        const floppy = document.getElementById(id);
        const li = floppy.querySelector('li'); 

        li.addEventListener('click', function() {
            let options;
            if (id === "floppyA") {
                options = [
                    'Disquetera de 3.5"',
                    'Disquetera de 3"',
                    'Archivo DSK',
                    'Desactivada'
                ];
            } else {
                options = [
                    'Disquetera de 3.5"',
                    'Disquetera de 3"',
                    'Archivo DSK',
                    'Desactivada',
                    'Interfaz Local'
                ];
            }

            const ul = this.parentNode; 

            ul.innerHTML = ''; 

            for (let option of options) {
                const newLi = document.createElement('li'); 
                const link = document.createElement('a');
                
                link.href = `javascript:void(0)`; // Evitar la navegación directa
                link.textContent = option;

                link.addEventListener('click', function(event) {
                    event.preventDefault(); // Evitar la navegación

                    // Realizar la solicitud AJAX
                    fetch(`${baseURL}setDrive?drive=${id}&option=${encodeURIComponent(option)}`)
                        .then(response => {
                            if (response.status === 200) {
                                return response.text();
                            }
                            throw new Error('Error en la petición');
                        })
                        .then(data => {
                            // Reemplazar el div existente con el nuevo div de la respuesta
                            const parser = new DOMParser();
                            const newDoc = parser.parseFromString(data, 'text/html');
                            const newDiv = newDoc.querySelector(`.floppy[id="${id}"]`);
                            const existingDiv = document.querySelector(`.floppy[id="${id}"]`);
                            existingDiv.replaceWith(newDiv);
                            
                            // Desplazarse hacia arriba
                            window.scrollTo(0, 0);
                            
                            // Vuelve a adjuntar los eventos al nuevo div
                            attachEvents(id);
                        })
                        .catch(error => {
                            console.error('Error:', error);
                        });
                });

                newLi.appendChild(link);

                if (option.trim() === this.textContent.trim()) { 
                    newLi.classList.add('selected'); 
                }

                ul.appendChild(newLi); 
            }
        });

        const selectedDskLi = floppy.querySelector('.selected-dsk-title + ul li');
        if (selectedDskLi) {
            selectedDskLi.addEventListener('click', function() {
                if (li.textContent.trim() === 'Archivo DSK') {
                    // Contraer todos los <li> expandidos dentro del <div> con clase "sdfiles"
                    const expandedItems = document.querySelectorAll('.sdfiles li');
                    expandedItems.forEach(item => {
                        // Eliminar botones
                        const buttons = item.querySelectorAll('button');
                        buttons.forEach(button => button.remove());

                        // Eliminar el mensaje de respuesta si existe
                        const responseDiv = item.querySelector('.response');
                        if (responseDiv) {
                            responseDiv.remove();
                        }
                    });

                    const sdFilesUl = document.querySelector('.sdfiles ul').cloneNode(true); // Clonar el ul
                    const dskFilesLis = Array.from(sdFilesUl.querySelectorAll('li.dsk, li.dsk-ext')); // Filtrar por clase

                    const ul = this.parentNode;
                    ul.innerHTML = '';

                    // Añadir la opción "Ningún DSK seleccionado"
                    const noDskLi = document.createElement('li');
                    const noDskLink = document.createElement('a');
                    noDskLink.href = `javascript:void(0)`; // Evitar la navegación directa
                    noDskLink.textContent = 'Ningún DSK seleccionado';

                    noDskLink.addEventListener('click', function(event) {
                        event.preventDefault(); // Evitar la navegación

                        // Realizar la solicitud AJAX
                        fetch(`${baseURL}setDrive?drive=${id}&option=${encodeURIComponent('Archivo DSK')}&file=none`)
                            .then(response => {
                                if (response.status === 200) {
                                    return response.text();
                                }
                                throw new Error('Error en la petición');
                            })
                            .then(data => {
                                // Reemplazar el div existente con el nuevo div de la respuesta
                                const parser = new DOMParser();
                                const newDoc = parser.parseFromString(data, 'text/html');
                                const newDiv = newDoc.querySelector(`.floppy[id="${id}"]`);
                                const existingDiv = document.querySelector(`.floppy[id="${id}"]`);
                                existingDiv.replaceWith(newDiv);
                                // Desplazarse hacia arriba
                                window.scrollTo(0, 0);
                                // Vuelve a adjuntar los eventos al nuevo div
                                attachEvents(id);
                            })
                            .catch(error => {
                                console.error('Error:', error);
                            });
                    });

                    noDskLi.appendChild(noDskLink);
                    ul.appendChild(noDskLi);

                    for (let dskLi of dskFilesLis) {
                        const dskFile = dskLi.textContent.trim();
                        const newLi = dskLi.cloneNode(true); // Clonar el li

                        const link = newLi.querySelector('a');
                        link.href = `javascript:void(0)`; // Evitar la navegación directa
                        link.addEventListener('click', function(event) {
                            event.preventDefault(); // Evitar la navegación

                            // Realizar la solicitud AJAX
                            fetch(`${baseURL}setDrive?drive=${id}&option=${encodeURIComponent('Archivo DSK')}&file=${encodeURIComponent(dskFile)}`)
                                .then(response => {
                                    if (response.status === 200) {
                                        return response.text();
                                    }
                                    throw new Error('Error en la petición');
                                })
                                .then(data => {
                                    // Reemplazar el div existente con el nuevo div de la respuesta
                                    const parser = new DOMParser();
                                    const newDoc = parser.parseFromString(data, 'text/html');
                                    const newDiv = newDoc.querySelector(`.floppy[id="${id}"]`);
                                    const existingDiv = document.querySelector(`.floppy[id="${id}"]`);
                                    existingDiv.replaceWith(newDiv);
                                    // Desplazarse hacia arriba
                                    window.scrollTo(0, 0);
                                    // Vuelve a adjuntar los eventos al nuevo div
                                    attachEvents(id);
                                })
                                .catch(error => {
                                    console.error('Error:', error);
                                });
                        });
                        
                        if (dskFile === this.textContent.trim()) { 
                            newLi.classList.add('selected'); 
                        }

                        ul.appendChild(newLi); 
                    }

                }
            });
        }

        // Asignar eventos a los botones "Cara A" y "Cara B"
        const swapButtons = document.querySelectorAll(`.floppy[id="${id}"] button[side-swap]`);
        swapButtons.forEach(function(button) {
            button.addEventListener('click', function() {
                const floppyElement = this.closest('.floppy');
                const floppyId = floppyElement.getAttribute('floppy-drive-id');
                const side = this.getAttribute('side-swap');
                Command_swapSide(this, floppyId, side);
            });
        });

    }

    const floppyElements = ['floppyA', 'floppyB']; // IDs de tus disqueteras

    floppyElements.forEach(function(id) {
        attachEvents(id);
    });



    function handleDriveButton(driveId, fileName, listItem) {
        fetch(`${baseURL}setDrive?drive=${driveId}&option=${encodeURIComponent('Archivo DSK')}&file=${encodeURIComponent(fileName)}`)
            .then(response => {
                if (response.status === 200) {
                    return response.text();
                }
                throw new Error('Error en la petición');
            })
            .then(data => {
                // Reemplazar el div existente con el nuevo div de la respuesta
                const parser = new DOMParser();
                const newDoc = parser.parseFromString(data, 'text/html');
                const newDiv = newDoc.querySelector(`.floppy[id="${driveId}"]`);
                const existingDiv = document.querySelector(`.floppy[id="${driveId}"]`);
                existingDiv.replaceWith(newDiv);

                // Desplazarse hacia arriba
                window.scrollTo(0, 0);
                // Vuelve a adjuntar los eventos al nuevo div
                attachEvents(driveId);

                // Contraer el <li> quitando los botones
                const buttons = listItem.querySelectorAll('button');
                buttons.forEach(button => button.remove());
            })
            .catch(error => {
                console.error('Error:', error);
            });
    }


    function Command_swapSide(buttonElement, floppyId, side) {
      // Determinar el ID del floppy drive (0 para A, 1 para B)
      var command = 'side_swap';
      var errorDivId = `${command}-error`;

      // Realizar la solicitud GET
      var xhr = new XMLHttpRequest();
      xhr.open('GET', `${baseURL}avrcommand?command=${command}&arg0=${floppyId}&arg1=${side}`, true);
      xhr.onreadystatechange = function() {
        if (xhr.readyState === 4) { // Si la solicitud se completó
          if (xhr.status === 200) { // Si el estado es OK
            Command_handleResponse(xhr.responseText, buttonElement, errorDivId);
          } else {
            Command_displayError('Error: no se recibió respuesta.', errorDivId);
          }
        }
      };
      xhr.send();
    }


    function Command_handleResponse(response, buttonElement, errorDivId) {
      var errorMessageDiv = document.getElementById(errorDivId);
      if (!errorMessageDiv) {
        console.error(`Elemento de mensaje de error con id ${errorDivId} no encontrado.`);
        return;
      }

      errorMessageDiv.textContent = ''; // Limpiar mensaje de error

      // Determinar la clase 'selected' según la respuesta
      if (response === 'sides_swapped' || response === 'sides_default') {
        var parentDiv = buttonElement.parentElement;
        var buttons = parentDiv.getElementsByTagName('button');
        for (var i = 0; i < buttons.length; i++) {
          buttons[i].classList.remove('selected');
        }
        buttonElement.classList.add('selected');
      } else {
        Command_displayError('Error: no se pudo hacer la acción solicitada.', errorDivId);
      }
    }


    function Command_displayError(message, errorDivId) {
      var errorMessageDiv = document.getElementById(errorDivId);
      if (!errorMessageDiv) {
        console.error(`Elemento de mensaje de error con id ${errorDivId} no encontrado.`);
        return;
      }
      errorMessageDiv.textContent = message;
    }



    // Código JavaScript para buscar archivos
    // Función para filtrar la lista de archivos dentro de sdfiles
    function filterFiles() {
        var sdfiles = document.querySelector('.sdfiles');
        var input = sdfiles.querySelector('.filter-input');
        if (!input) return; // Asegurarse de que el input existe
        var filter = input.value.toUpperCase().replace(/\s/g, '');
        var ul = sdfiles.querySelector('.files');
        var li = ul.getElementsByTagName('li');
        var clearBtn = sdfiles.querySelector('.clear-btn');
        if (!clearBtn) return; // Asegurarse de que el botón limpiar existe

        for (var i = 0; i < li.length; i++) {
            var a = li[i].getElementsByTagName('a')[0];
            var txtValue = a.textContent || a.innerText;
            var filename = txtValue.toUpperCase().replace(/\s/g, '');
            if (filename.indexOf(filter) > -1) {
                li[i].style.display = '';
            } else {
                li[i].style.display = 'none';
            }
        }

        // Mostrar/ocultar botón "Limpiar"
        if (input.value.length > 0) {
            clearBtn.style.display = 'inline';
        } else {
            clearBtn.style.display = 'none';
        }
    }

    // Función para limpiar el campo de búsqueda y restaurar la lista completa dentro de sdfiles
    function clearFilter() {
        var sdfiles = document.querySelector('.sdfiles');
        var input = sdfiles.querySelector('.filter-input');
        if (!input) return; // Asegurarse de que el input existe
        input.value = '';
        filterFiles();
    }

    // Añadir eventos para el input y el botón "Limpiar" dentro de sdfiles
    var sdfiles = document.querySelector('.sdfiles');
    if (sdfiles) {
        var filterInput = sdfiles.querySelector('.filter-input');
        if (filterInput) {
            filterInput.addEventListener('keyup', filterFiles);
        }
        var clearBtn = sdfiles.querySelector('.clear-btn');
        if (clearBtn) {
            clearBtn.addEventListener('click', clearFilter);
        }
    }



    // Código JavaScript para cargar el listado de archivos mediante chunked transfer encoding
    function fetchFilesChunked() {

        // Obtenemos el número de archivos para la barra de progreso
        let numberOfFiles = 0;
        const sdFilesTitleText = document.querySelector('.sdfiles .sdfiles-title').textContent;
        const match = sdFilesTitleText.match(/\((\d+)\)/);
        if (match) {
            numberOfFiles = parseInt(match[1], 10);
            console.log(`Número de archivos: ${numberOfFiles}`);
        } else {
            console.log('No se pudo encontrar el número de archivos.');
        }

        // Código HTML base para la barra de progreso
        const sdfilesprogresshtml = `
        <div class="progressbarelement">
            <div class="title">Cargando archivos..</div>
            <div class="progressbar">
                <div id="sdfilesprogressbar"></div>
            </div>
            <div class="progress">0/${numberOfFiles}</div>
        </div>
        `;
        // Insertamos el HTML dentro de div.sdfiles justo antes del elemento ul.files
        document.querySelector('.sdfiles ul.files').insertAdjacentHTML('beforebegin', sdfilesprogresshtml);
        
        // Para ir actualizando la barra de progreso
        const progressElement = document.querySelector('.sdfiles .progressbarelement .progress');
        const progressBarElement = document.getElementById('sdfilesprogressbar');
        let filesReceived = 0;

        // Ocultamos el elemento <ul> y el buscador hasta que carguen los archivos
        const ulFilesElement = document.querySelector('.sdfiles ul.files');
        ulFilesElement.style.display = 'none';
        const searchFilesElement = document.querySelector('.sdfiles .filter-container');
        searchFilesElement.style.display = 'none';

        const xhr = new XMLHttpRequest();
        xhr.open("GET", `/getsdfilelistchunked`, true);

        let buffer = '';

        xhr.onreadystatechange = function () {
            if (xhr.readyState === 3 || xhr.readyState === 4) {
                // Procesar los datos recibidos
                const filesContainer = document.querySelector("div.sdfiles ul.files");
                buffer += xhr.responseText.substring(xhr.seenBytes);
                xhr.seenBytes = xhr.responseText.length;

                // Procesar el buffer para extraer los elementos completos
                let lastIndex = buffer.lastIndexOf("</li>");
                if (lastIndex !== -1) {
                    const newContent = buffer.substring(0, lastIndex + 5); // +5 to include "</li>"
                    buffer = buffer.substring(lastIndex + 5); // Retain the rest in the buffer

                    // Insertar el contenido en el contenedor
                    const tempDiv = document.createElement("div");
                    tempDiv.innerHTML = newContent;
                    const newItems = tempDiv.querySelectorAll("li");
                    newItems.forEach(item => {
                        filesContainer.appendChild(item);
                        filesReceived++;

                        // Actualizar el contador y la barra de progreso
                        progressElement.textContent = `${filesReceived}/${numberOfFiles}`;
                        const progressPercentage = (filesReceived / numberOfFiles) * 100;
                        progressBarElement.style.width = `${progressPercentage}%`;

                        // Quitar el elemento de progreso cuando llegue al 100%
                        if (filesReceived === numberOfFiles) {
                            const progressBarElement = document.querySelector(".progressbarelement");
                            progressBarElement.parentNode.removeChild(progressBarElement);
                        }
                    });
                }

                // Verificar si la transferencia está completa
                if (xhr.readyState === 4 && xhr.status === 200) {
                    // Procesar cualquier elemento restante en el buffer
                    if (buffer.length > 0) {
                        const tempDiv = document.createElement("div");
                        tempDiv.innerHTML = buffer;
                        const newItems = tempDiv.querySelectorAll("li");
                        newItems.forEach(item => {
                            filesContainer.appendChild(item);
                            filesReceived++;

                            // Actualizar el contador y la barra de progreso
                            progressElement.textContent = `${filesReceived}/${numberOfFiles}`;
                            const progressPercentage = (filesReceived / numberOfFiles) * 100;
                            progressBarElement.style.width = `${progressPercentage}%`;

                            // Quitar el elemento de progreso cuando llegue al 100%
                            if (filesReceived === numberOfFiles) {
                                const progressBarElement = document.querySelector(".progressbarelement");
                                progressBarElement.parentNode.removeChild(progressBarElement);
                            }
                        });
                        buffer = ''; // Limpiar el buffer
                    }

                    // Mostrar el elemento ul y el buscador después de cargar los archivos
                    searchFilesElement.removeAttribute('style');
                    ulFilesElement.removeAttribute('style');

                    // Comportamiento para el botón "Bajar"
                    document.querySelector('.go-down-btn').addEventListener('click', function() {
                        console.log("Bajar clicado");
                        //var sdfilesDiv = document.querySelector('.sdfiles');
                        //sdfilesDiv.scrollIntoView({ behavior: 'smooth', block: 'end' });
                        window.scrollTo(0, document.body.scrollHeight);
                    });

                    // Añadimos los event listeners a los elementos <li>
                    attachFileItemBehaviors();  // Re-attach event listeners to new items
                    const loadingMsg = document.querySelector(".loading-msg");
                    loadingMsg.style.display = "none";
                }
            }
        };

      xhr.seenBytes = 0;
      xhr.send();
    }

    const loadingMsg = document.querySelector(".loading-msg");
    if (loadingMsg) {
      fetchFilesChunked();
    }






    // Código JavaScript para formatear una tarjeta microSD
    const microsdInfoDiv = document.querySelector(".microsd-info");
    if (microsdInfoDiv) {
        let firstButtonClicked = false;

        microsdInfoDiv.addEventListener("click", function(event) {
            if (event.target && event.target.matches("button.format")) {
                if (firstButtonClicked) return;

                firstButtonClicked = true;
                fetch('/formatsdcard')
                    .then(response => response.text())
                    .then(html => {
                        microsdInfoDiv.insertAdjacentHTML('beforeend', html);

                        const secondButton = microsdInfoDiv.querySelector(".formatconfirm[id]");
                        if (secondButton) {
                            secondButton.addEventListener("click", function() {
                                microsdInfoDiv.insertAdjacentHTML('beforeend', '<br><br>Formateando tarjeta microSD... No tarda más de 5 segundos.<br>');
                                const code = secondButton.id;
                                fetch(`/formatsdcard?code=${code}`)
                                    .then(response => response.text())
                                    .then(responseText => {
                                        let message;
                                        if (responseText === "ERROR") {
                                            message = "Error: No se pudo formatear correctamente la tarjeta microSD.";
                                        } else if (responseText === "OK") {
                                            message = "<div style=\"color: #01ff00;\">La tarjeta microSD se formateó con éxito.</div><br><br>Recargando página en 3 segundos..";
                                            setTimeout(() => location.reload(), 3000);
                                        }
                                        microsdInfoDiv.insertAdjacentHTML('beforeend', `<p>${message}</p>`);
                                    })
                                    .catch(error => {
                                        console.error('Error:', error);
                                        microsdInfoDiv.insertAdjacentHTML('beforeend', '<p>Error: No se pudo realizar la solicitud.</p>');
                                    });
                            });
                        }
                    })
                    .catch(error => {
                        console.error('Error:', error);
                        microsdInfoDiv.insertAdjacentHTML('beforeend', '<p>Error: No se pudo realizar la solicitud.</p>');
                    });
            }
        });
    }







    // Código para el comportamiento del listado de archivos
    function attachFileItemBehaviors() {
        const fileItems = document.querySelectorAll('div.sdfiles ul.files li');
        console.log(`attachFileItemBehaviors called. Found ${fileItems.length} items.`);
        fileItems.forEach(item => {
            item.removeEventListener('click', handleFileItemClick);  // Remove existing listeners to avoid duplicates
            item.addEventListener('click', handleFileItemClick);
            //console.log(`Event listener added to item with text: ${item.querySelector('a').textContent}`);
        });
    }


    function handleFileItemClick() {
        const item = event.currentTarget;
        const fileItems = document.querySelectorAll('div.sdfiles ul.files li');
        // Contraer cualquier otro <li> expandido
        fileItems.forEach(otherItem => {
            if (otherItem !== this) {
                // Eliminar botones
                const buttons = otherItem.querySelectorAll('button');
                buttons.forEach(button => button.remove());
            }

            // Eliminar el mensaje de respuesta si existe (movido fuera de la condición anterior)
            const responseDiv = otherItem.querySelector('.response');
            if (responseDiv) {
                responseDiv.remove();
            }
        });

        // Si el <li> actual ya está expandido, contraerlo
        if (this.querySelector('button')) {
            const buttons = this.querySelectorAll('button');
            buttons.forEach(button => button.remove());
            return;
        }

        const fileName = this.querySelector('a').textContent;
        const encodedFileName = encodeURIComponent(fileName);
        let buttonsHtml = '';

        // Añadir botones "Disquetera A" y "Disquetera B" si el <li> tiene la clase "dsk" o "dsk-ext"
        if (this.classList.contains('dsk') || this.classList.contains('dsk-ext')) {
            buttonsHtml += `
                <button type="submit" id="driveAButton">Disquetera A</button>
                <button type="submit" id="driveBButton">Disquetera B</button>
            `;
        }

        buttonsHtml += `
            <button type="submit" class="download">Descargar</button>
            <button type="submit" class="view">Ver</button>
            <button type="submit" class="delete">Eliminar</button>
        `;

        this.innerHTML += buttonsHtml;
        
        // Agregar el comportamiento al botón "Disquetera A"
        let driveAButton = this.querySelector('#driveAButton');
        if (driveAButton) {
            driveAButton.addEventListener('click', function(event) {
                event.stopPropagation();
                handleDriveButton('floppyA', fileName, this);
            });
        }

        // Agregar el comportamiento al botón "Disquetera B"
        let driveBButton = this.querySelector('#driveBButton');
        if (driveBButton) {
            driveBButton.addEventListener('click', function(event) {
                event.stopPropagation();
                handleDriveButton('floppyB', fileName, this);
            });
        }

        // Agregar el comportamiento al botón "Ver datos"
        this.querySelector('.view').addEventListener('click', function(event) {
            event.stopPropagation();
            window.location.href = `/readDSK?name=${encodedFileName}`;
        });

        // Agregar el comportamiento al botón "Ver datos"
        this.querySelector('.download').addEventListener('click', function(event) {
            event.stopPropagation();
            window.location.href = `/download?name=${encodedFileName}`;
        });

        const deleteButton = this.querySelector('.delete');
        deleteButton.addEventListener('click', function(event) {
            event.stopPropagation();
            if (this.textContent === 'Eliminar') {
                this.textContent = 'Confirmar';
            } else if (this.textContent === 'Confirmar') {
                // Si ya hay un div de respuesta, lo eliminamos
                const existingResponseDiv = item.querySelector('.response');
                if (existingResponseDiv) {
                    existingResponseDiv.remove();
                }

                // Mostrar el mensaje "Eliminando..."
                const responseDiv = document.createElement('div');
                responseDiv.className = 'response';
                responseDiv.textContent = 'Eliminando...';
                item.appendChild(responseDiv);

                fetch(`/deleteFile?file=${encodedFileName}`)
                    .then(response => {
                        if (response.status === 200) {
                            return response.text();
                        }
                        throw new Error('Error en la petición');
                    })
                    .then(data => {
                        // Reemplazar el mensaje "Eliminando..." con la respuesta del servidor
                        responseDiv.textContent = data;

                        if (data === 'Archivo eliminado correctamente') {
                            // Quitar los botones
                            const buttons = item.querySelectorAll('button');
                            buttons.forEach(btn => btn.remove());

                            // Iniciar la cuenta atrás
                            let countdown = 3;
                            const countdownDiv = document.createElement('div');
                            countdownDiv.textContent = `Quitando del listado en ${countdown}...`;
                            item.appendChild(countdownDiv);

                            const interval = setInterval(() => {
                                countdown--;
                                if (countdown <= 0) {
                                    clearInterval(interval);
                                    item.remove();
                                } else {
                                    countdownDiv.textContent = `Quitando del listado en ${countdown}...`;
                                }
                            }, 1000);
                        }
                    })
                    .catch(error => {
                        console.error('Error:', error);
                        responseDiv.textContent = 'Error al eliminar el archivo.';
                    });
            }
        });
    };


    // Código JavaScript para desactivar la Interfaz Local en Disqetera A sin refrescar la página
    const form = document.getElementById("disableli-form");
    const box = document.getElementById("disableli-box");

    if (form && box) { // Comprobar si el formulario y la caja existen
        form.addEventListener("submit", function(event) {
            event.preventDefault(); // Evitar el refresco de la página

            // Crear un objeto XMLHttpRequest
            const xhr = new XMLHttpRequest();
            xhr.open("GET", form.action + "?option=disableli", true);

            xhr.onload = function() {
                if (xhr.status === 200 && xhr.responseText === "OK") {
                    // Eliminar la caja si la respuesta es "OK"
                    box.parentNode.removeChild(box);
                } else {
                    console.error("Error en la solicitud AJAX:", xhr.status, xhr.responseText);
                }
            };

            xhr.onerror = function() {
                console.error("Solicitud AJAX fallida");
            };

            // Enviar la solicitud AJAX
            xhr.send();
        });
    }


});



// Código JavaScript para la subida múltiple de archivos
function uploadFiles() {
    const files = document.getElementById('fileInput').files;
    const progressContainer = document.getElementById('progressContainer');
    progressContainer.innerHTML = '';
    if (files.length === 0) {
        alert('Por favor, seleccione al menos un archivo.');
        return;
    }
    
    let currentIndex = 0;
    let hadError = false;

    function uploadNext() {
        if (currentIndex >= files.length) {
            if (!hadError) {
                progressContainer.innerHTML += '<br>Archivos subidos con éxito';
            }
            setTimeout(() => {
                window.location.reload();
            }, 2000);
            return;
        }

        const file = files[currentIndex];
        const formData = new FormData();
        formData.append('file', file);
        //formData.append('lastModified', Math.floor(file.lastModified / 1000));

        const xhr = new XMLHttpRequest();
        xhr.open('POST', '/uploadmulti', true);

        // Header con la fecha de modificación del archivo para preservarla
        xhr.setRequestHeader('Lastmodified', Math.floor(file.lastModified / 1000));

        xhr.upload.onprogress = function (e) {
            if (e.lengthComputable) {
                const percentComplete = (e.loaded / e.total) * 100;
                progressContainer.innerHTML = `Subiendo archivo ${currentIndex + 1}/${files.length}.. ${Math.round(percentComplete)}%`;
            }
        };

        xhr.onload = function () {
            if (xhr.status === 200 && xhr.responseText === "OK") {
                currentIndex++;
                uploadNext();
            } else {
                hadError = true;
                progressContainer.innerHTML += `<br>Fallo al subir archivo ${file.name}: ${xhr.responseText}`;
                currentIndex++;
                uploadNext();
            }
        };

        xhr.send(formData);
    }

    uploadNext();
}



